<?php

namespace App\Http\Livewire;

use App\Models\category;
use Livewire\Component;
use Livewire\WithPagination;

class Categorywire extends Component
{
    use WithPagination;
    protected $paginationTheme = 'bootstrap';
    
    public $searchId;
    public $search_descripcion;
    public $search_name;
    public $search_fecha;
    public $search_cateSup;

    public $descripcion;
    public $category_superior=0;

    public $titulo='Agregar Categoría';
    public $btn='Registrar';

    public $id_eliminar;
    public $id_almacen=0;

    protected $listeners=['render'=>'render'];

    protected $rules=[
        "descripcion"=>"required"
    ];

    protected $messages = [
        'descripcion.required' => 'se debe ingresar un nombre para la categoría.'
    ];

    public function render()
    {
        if($this->search_cateSup==null || $this->search_cateSup==''){
            $datosSistem['category'] = category::
            select('category.id','category.name as descripcion','supCategory.name as cateSup','users.name', 'category.updated_at')
            ->join('users', 'users.id', '=', 'category.user_update' )
            ->leftJoin('category as supCategory', 'supCategory.id', '=', 'category.id_category_sup' )
            ->where('category.id','like', '%'.$this->searchId.'%')
            ->where('category.name','like', '%'.$this->search_descripcion.'%')
            ->where('users.name','like', '%'.$this->search_name.'%')
            ->where('category.updated_at','like', '%'.$this->search_fecha.'%')
            ->where('category.estado', 1)
            ->orderBy('category.id','desc')
            ->paginate(10);
        }else{
            $datosSistem['category'] = category::
            select('category.id','category.name as descripcion','supCategory.name as cateSup','users.name', 'category.updated_at')
            ->join('users', 'users.id', '=', 'category.user_update' )
            ->leftJoin('category as supCategory', 'supCategory.id', '=', 'category.id_category_sup' )
            ->where('category.id','like', '%'.$this->searchId.'%')
            ->where('category.name','like', '%'.$this->search_descripcion.'%')
            ->where('users.name','like', '%'.$this->search_name.'%')
            ->where('category.updated_at','like', '%'.$this->search_fecha.'%')
            ->where('supCategory.name','like', '%'.$this->search_cateSup.'%')
            ->where('category.estado', 1)
            ->orderBy('category.id','desc')
            ->paginate(10);
        }

        $datosSistem['category_superior'] = category::
        select('category.id','category.name as descripcion')
        ->where('category.estado', 1)
        ->where('category.id','!=', 1)
        ->orderBy('category.id','desc')
        ->get();

        return view('livewire.categorywire', compact('datosSistem'));
    }

    public function save(){

        $this->validate();

        if($this->id_almacen==0){
            $category = category::
            select('id')
            ->where('name', trim($this->descripcion))
            ->where('estado',1)
            ->get();
    
            $validExist=0;
            foreach($category as $row){
                $validExist++;
            }
    
            if($validExist==0){
                if($this->category_superior == null){
                    category::create([
                        'name'=>trim($this->descripcion),
                        'id_category_sup'=>$this->category_superior,
                        'estado'=>1,
                        'user_create'=>auth()->user()->id,
                        'user_update'=>auth()->user()->id
                    ]);
                }else{
                    category::create([
                        'name'=>trim($this->descripcion),
                        'id_category_sup'=>$this->category_superior,
                        'estado'=>1,
                        'user_create'=>auth()->user()->id,
                        'user_update'=>auth()->user()->id
                    ]);
                }
                
                $this->reset(['id_eliminar', 'descripcion','category_superior','titulo','btn','id_almacen']);
                $this->emit('render');
                $this->emit('alertOK','Se registro la categoría con exito.');
            }else{
                $this->emit('alertError','El nombre ingresado está siendo utilizado en otra categoría.');
            }
        }else{
            $category = category::
            select('id')
            ->where('name', trim($this->descripcion))
            ->where('id','<>', $this->id_almacen)
            ->where('estado',1)
            ->get();
    
            $validExist=0;
            foreach($category as $row){
                $validExist++;
            }

            if($validExist==0){
                category::where('id',$this->id_almacen)
                ->update([
                    'name'=>trim($this->descripcion),
                    'id_category_sup'=>$this->category_superior,
                    'user_update'=>auth()->user()->id
                ]);
        
                $this->reset(['id_eliminar', 'descripcion','category_superior','titulo','btn','id_almacen']);
                $this->emit('render');
                $this->emit('alertOK','Se edito la categoría con exito.');
            }else{
                $this->emit('alertError','El nombre ingresado está siendo utilizado en otra categoría.');
            }
        }
        
    }

    public function eliminarID($id){
        $this->id_eliminar=$id;
    }

    public function delete_categoria(){
        category::where('id',$this->id_eliminar)
        ->update([
        'estado'=>0,
        'user_update'=>auth()->user()->id]);

        category::where('id_category_sup',$this->id_eliminar)
        ->update([
        'id_category_sup'=>0,
        'user_update'=>auth()->user()->id]);

        $this->reset(['id_eliminar', 'descripcion','category_superior','titulo','btn','id_almacen']);
        $this->emit('render');
        $this->emit('alertOK','Se elimino la categoría con exito.');
    }

    public function modificarID($id){
        $this->id_almacen=$id;

        $mark = category::
        select('name','id_category_sup')
        ->where('id', $id)
        ->get();

        foreach($mark as $row){
            $this->descripcion=$row->name;
            $this->category_superior=(String)$row->id_category_sup;
        }

        $this->titulo='Editar categoría N° '. $id;
        $this->btn='Editar';

    }

    public function limpiar(){
        $this->reset(['id_eliminar', 'descripcion','category_superior','titulo','btn','id_almacen']);
    }

    public function updatingSearchid(){
        $this->resetPage();
    }

    public function updatingSearchname(){
        $this->resetPage();
    }

    public function updatingSearchdescripcion(){
        $this->resetPage();
    }

    public function updatingSearchfecha(){
        $this->resetPage();
    }
    
    public function updatingSearchcateSup(){
        $this->resetPage();
    }

}
