<?php

namespace App\Http\Livewire;

use App\Models\customer;
use App\Models\setting;
use Livewire\Component;
use Livewire\WithPagination;

class Customerwire extends Component
{
    use WithPagination;
    protected $paginationTheme = 'bootstrap';
    
    public $searchId;
    public $search_descripcion;
    public $search_direccion;
    public $search_dni;
    public $search_ruc;
    public $search_pasaporte;
    public $search_carnet;

    public $descripcion;
    public $direccion;
    public $dni;
    public $ruc;
    public $pasaporte;
    public $carnet;

    public $titulo;
    public $btn='Registrar';
    public $tipo_tituloMinus;
    public $tipo_tituloMayus;

    public $id_eliminar;
    public $id_customer=0;

    protected $listeners=['render'=>'render'];

    protected $rules=[
        "descripcion"=>"required",
        "direccion"=>"required",
    ];

    protected $messages = [
        'descripcion.required' => 'se debe ingresar un nombre.',
        'direccion.required' => 'se debe ingresar una dirección.',
    ];

    public function mount(){
        $setting = setting::
        select('id_type_business')
        ->get();

        $tipo_negocio=0;
        foreach($setting as $rowSetting){
            $tipo_negocio = $rowSetting->id_type_business;
        }

        if($tipo_negocio==2){
            $this->titulo='Agregar Padre';
            $this->tipo_tituloMinus='Padres';
            $this->tipo_tituloMayus='PADRES';
        }else{
            $this->titulo='Agregar Cliente';
            $this->tipo_tituloMinus='Clientes';
            $this->tipo_tituloMayus='CLIENTES';
        }
    }

    public function render()
    {
        $datosSistem['customer'] = customer::
        select('id','nombre as descripcion','direccion', 'dni','ruc','pasaporte','carnet')
        ->where('id','like', '%'.$this->searchId.'%')
        ->where('nombre','like', '%'.$this->search_descripcion.'%')
        ->where('direccion','like', '%'.$this->search_direccion.'%')
        ->where('dni','like', '%'.$this->search_dni.'%')
        ->where('ruc','like', '%'.$this->search_ruc.'%')
        ->where('pasaporte','like', '%'.$this->search_pasaporte.'%')
        ->where('carnet','like', '%'.$this->search_carnet.'%')
        ->where('estado', 1)
        ->orderBy('id','desc')
        ->paginate(10);

        return view('livewire.customerwire', compact('datosSistem'));
    }

    public function save(){

        $this->validate();

        $validDocument=0;
        if(trim($this->dni)=='' || $this->dni==null){
            $validDocument++;
        }

        if(trim($this->ruc)=='' || $this->ruc==null){
            $validDocument++;
        }

        if(trim($this->pasaporte)=='' || $this->pasaporte==null){
            $validDocument++;
        }

        if(trim($this->carnet)=='' || $this->carnet==null){
            $validDocument++;
        }

        if($validDocument<4){

            if($this->id_customer==0){

                $valid=0;
                $textError='';
                if(trim($this->dni)!='' && $this->dni!=null){
                    if(is_numeric(trim($this->dni))){
                        if(!is_int(trim($this->dni)*1) || strlen(trim($this->dni))!=8){
                            $valid++;
                            $textError=$textError. PHP_EOL .'* Error en formato de Dni';
                        }else{
                            $validDni = customer::
                            select('id')
                            ->where('dni', trim($this->dni))
                            ->where('estado',1)
                            ->get();
                        
                            $valid_dni=0;
                            foreach($validDni as $rowDni){
                                $valid_dni++;
                            }
    
                            if($valid_dni>0){
                                $valid++;
                                $textError=$textError. PHP_EOL .'* El Dni ya fue registrado en otro cliente';
                            }
                        }
                    }else{
                        $valid++;
                        $textError=$textError. PHP_EOL .'* Error en formato de Dni';
                    }
                }

                if(trim($this->ruc)!='' && $this->ruc!=null){
                    if(is_numeric(trim($this->ruc))){
                        if(!is_int(trim($this->ruc)*1) || strlen(trim($this->ruc))!=11){
                            $valid++;
                            $textError=$textError. PHP_EOL .'* Error en formato de Ruc';
                        }else{
                            $validRuc = customer::
                            select('id')
                            ->where('ruc', trim($this->ruc))
                            ->where('estado',1)
                            ->get();
                        
                            $valid_ruc=0;
                            foreach($validRuc as $rowRuc){
                                $valid_ruc++;
                            }
    
                            if($valid_ruc>0){
                                $valid++;
                                $textError=$textError. PHP_EOL .'* El Ruc ya fue registrado en otro cliente';
                            }
                        }
                    }else{
                        $valid++;
                        $textError=$textError. PHP_EOL .'* Error en formato de Ruc';
                    }
                    
                }

                if(trim($this->pasaporte)!='' && $this->pasaporte!=null){
                    $validPasa = customer::
                    select('id')
                    ->where('pasaporte', trim($this->pasaporte))
                    ->where('estado',1)
                    ->get();
                
                    $valid_pasa=0;
                    foreach($validPasa as $rowPasa){
                        $valid_pasa++;
                    }
                    if($valid_pasa>0){
                        $valid++;
                        $textError=$textError. PHP_EOL .'* El Pasaporte ya fue registrado en otro cliente';
                    }
                }

                if(trim($this->carnet)!='' && $this->carnet!=null){
                    $validCarnet = customer::
                    select('id')
                    ->where('carnet', trim($this->carnet))
                    ->where('estado',1)
                    ->get();
                
                    $valid_Carnet=0;
                    foreach($validCarnet as $rowCarnet){
                        $valid_Carnet++;
                    }
                    if($valid_Carnet>0){
                        $valid++;
                        $textError=$textError. PHP_EOL .'* El Carnet de extrajeria ya fue registrado en otro cliente';
                    }
                }

                $validNomb = customer::
                select('id')
                ->where('nombre', trim($this->descripcion))
                ->where('estado',1)
                ->get();
            
                $valid_Nomb=0;
                foreach($validNomb as $rowNomb){
                    $valid_Nomb++;
                }
                if($valid_Nomb>0){
                    $valid++;
                    $textError=$textError. PHP_EOL .'* El Nombre del cliente ya fue utilizado en otro cliente';
                }

                if($valid==0){
                    customer::create([
                        'nombre'=>trim($this->descripcion),
                        'direccion'=>trim($this->direccion),
                        'dni'=>trim($this->dni),
                        'ruc'=>trim($this->ruc),
                        'pasaporte'=>trim($this->pasaporte),
                        'carnet'=>trim($this->carnet),
                        'estado'=>1,
                        'user_create'=>auth()->user()->id,
                        'user_update'=>auth()->user()->id
                    ]);

                    $setting = setting::
                    select('id_type_business')
                    ->get();

                    $tipo_negocio=0;
                    foreach($setting as $rowSetting){
                        $tipo_negocio = $rowSetting->id_type_business;
                    }

                    if($tipo_negocio==2){
                        $this->titulo='Agregar Padre';
                    }else{
                        $this->titulo='Agregar Cliente';
                    }

                    $this->reset(['descripcion','direccion','dni','ruc','pasaporte','carnet','btn','id_eliminar','id_customer']);
                    $this->emit('render');
                    $this->emit('alertOK','Se registro el cliente con exito.');
                }else{
                    $this->emit('alertError','se presentaron los siguientes errores:'. 
                    $textError);
                }

            }else{
                $valid=0;
                $textError='';
                if(trim($this->dni)!='' && $this->dni!=null){
                    if(is_numeric(trim($this->dni))){
                        if(!is_int(trim($this->dni)*1) || strlen(trim($this->dni))!=8){
                            $valid++;
                            $textError=$textError. PHP_EOL .'* Error en formato de Dni';
                        }else{
                            $validDni = customer::
                            select('id')
                            ->where('dni', trim($this->dni))
                            ->where('estado',1)
                            ->where('id','!=',$this->id_customer)
                            ->get();
                        
                            $valid_dni=0;
                            foreach($validDni as $rowDni){
                                $valid_dni++;
                            }
    
                            if($valid_dni>0){
                                $valid++;
                                $textError=$textError. PHP_EOL .'* El Dni ya fue registrado en otro cliente';
                            }
                        }
                    }else{
                        $valid++;
                        $textError=$textError. PHP_EOL .'* Error en formato de Dni';
                    }
                }

                if(trim($this->ruc)!='' && $this->ruc!=null){
                    if(is_numeric(trim($this->ruc))){
                        if(!is_int(trim($this->ruc)*1) || strlen(trim($this->ruc))!=11){
                            $valid++;
                            $textError=$textError. PHP_EOL .'* Error en formato de Ruc';
                        }else{
                            $validRuc = customer::
                            select('id')
                            ->where('ruc', trim($this->ruc))
                            ->where('estado',1)
                            ->where('id','!=',$this->id_customer)
                            ->get();
                        
                            $valid_ruc=0;
                            foreach($validRuc as $rowRuc){
                                $valid_ruc++;
                            }
    
                            if($valid_ruc>0){
                                $valid++;
                                $textError=$textError. PHP_EOL .'* El Ruc ya fue registrado en otro cliente';
                            }
                        }
                    }else{
                        $valid++;
                        $textError=$textError. PHP_EOL .'* Error en formato de Ruc';
                    }
                }

                if(trim($this->pasaporte)!='' && $this->pasaporte!=null){
                    $validPasa = customer::
                    select('id')
                    ->where('pasaporte', trim($this->pasaporte))
                    ->where('estado',1)
                    ->where('id','!=',$this->id_customer)
                    ->get();
                
                    $valid_pasa=0;
                    foreach($validPasa as $rowPasa){
                        $valid_pasa++;
                    }
                    if($valid_pasa>0){
                        $valid++;
                        $textError=$textError. PHP_EOL .'* El Pasaporte ya fue registrado en otro cliente';
                    }
                }

                if(trim($this->carnet)!='' && $this->carnet!=null){
                    $validCarnet = customer::
                    select('id')
                    ->where('carnet', trim($this->carnet))
                    ->where('estado',1)
                    ->where('id','!=',$this->id_customer)
                    ->get();
                
                    $valid_Carnet=0;
                    foreach($validCarnet as $rowCarnet){
                        $valid_Carnet++;
                    }
                    if($valid_Carnet>0){
                        $valid++;
                        $textError=$textError. PHP_EOL .'* El Carnet de extrajeria ya fue registrado en otro cliente';
                    }
                }

                $validNomb = customer::
                select('id')
                ->where('nombre', trim($this->descripcion))
                ->where('estado',1)
                ->where('id','!=',$this->id_customer)
                ->get();
            
                $valid_Nomb=0;
                foreach($validNomb as $rowNomb){
                    $valid_Nomb++;
                }
                if($valid_Nomb>0){
                    $valid++;
                    $textError=$textError. PHP_EOL .'* El Nombre del cliente ya fue utilizado en otro cliente';
                }

                if($valid==0){
                    customer::where('id',$this->id_customer)
                    ->update([
                        'nombre'=>trim($this->descripcion),
                        'direccion'=>trim($this->direccion),
                        'dni'=>trim($this->dni),
                        'ruc'=>trim($this->ruc),
                        'pasaporte'=>trim($this->pasaporte),
                        'carnet'=>trim($this->carnet),
                        'user_update'=>auth()->user()->id
                    ]);

                    $setting = setting::
                    select('id_type_business')
                    ->get();

                    $tipo_negocio=0;
                    foreach($setting as $rowSetting){
                        $tipo_negocio = $rowSetting->id_type_business;
                    }

                    if($tipo_negocio==2){
                        $this->titulo='Agregar Padre';
                    }else{
                        $this->titulo='Agregar Cliente';
                    }

                    $this->reset(['descripcion','direccion','dni','ruc','pasaporte','carnet','btn','id_eliminar','id_customer']);
                    $this->emit('render');
                    $this->emit('alertOK','Se modifico el cliente con exito.');
                }else{
                    $this->emit('alertError','se presentaron los siguientes errores:'. 
                    $textError);
                }
            }

            
            
        }else{
            $this->emit('alertError','Se debe de ingresar un Dni, Ruc, Pasaporte o Carnet de extrajeria.');
        }

    }

    public function modificarID($id){
        $this->id_customer=$id;

        $Categoria = customer::
        select('nombre','direccion', 'dni','ruc','pasaporte','carnet')
        ->where('id', $id)
        ->get();

        foreach($Categoria as $row){
            $this->descripcion=$row->nombre;
            $this->direccion=$row->direccion;
            $this->dni=$row->dni;
            $this->ruc=$row->ruc;
            $this->pasaporte=$row->pasaporte;
            $this->carnet=$row->carnet;
        }

        $setting = setting::
        select('id_type_business')
        ->get();

        $tipo_negocio=0;
        foreach($setting as $rowSetting){
            $tipo_negocio = $rowSetting->id_type_business;
        }

        if($tipo_negocio==2){
            $this->titulo='Editar Padre N° '. $id;
        }else{
            $this->titulo='Editar Cliente N° '. $id;
        }

        $this->btn='Editar';

    }

    public function eliminarID($id){
        $this->id_eliminar=$id;
    }

    public function delete_customer(){
        customer::where('id',$this->id_eliminar)
        ->update([
        'estado'=>0,
        'user_update'=>auth()->user()->id]);

        $setting = setting::
        select('id_type_business')
        ->get();

        $tipo_negocio=0;
        foreach($setting as $rowSetting){
            $tipo_negocio = $rowSetting->id_type_business;
        }

        if($tipo_negocio==2){
            $this->titulo='Agregar Padre';
        }else{
            $this->titulo='Agregar Cliente';
        }

        $this->reset(['descripcion','direccion','dni','ruc','pasaporte','carnet','btn','id_eliminar','id_customer']);
        $this->emit('render');
        $this->emit('alertOK','Se elimino el cliente con exito.');
    }

    public function limpiar(){
        $setting = setting::
        select('id_type_business')
        ->get();

        $tipo_negocio=0;
        foreach($setting as $rowSetting){
            $tipo_negocio = $rowSetting->id_type_business;
        }

        if($tipo_negocio==2){
            $this->titulo='Agregar Padre';
        }else{
            $this->titulo='Agregar Cliente';
        }

        $this->reset(['descripcion','direccion','dni','ruc','pasaporte','carnet','btn','id_eliminar','id_customer']);
        $this->emit('render');
    }

    public function updatingSearchid(){
        $this->resetPage();
    }

    public function updatingSearchdescripcion(){
        $this->resetPage();
    }

    public function updatingSearchdireccion(){
        $this->resetPage();
    }

    public function updatingSearchdni(){
        $this->resetPage();
    }

    public function updatingSearchruc(){
        $this->resetPage();
    }

    public function updatingSearchpasaporte(){
        $this->resetPage();
    }

    public function updatingSearchcarnet(){
        $this->resetPage();
    }

}
