<?php

namespace App\Http\Livewire;

use App\Models\customer;
use App\Models\identificador_alumno;
use Livewire\Component;
use Livewire\WithPagination;

class Identalumnwire extends Component
{
    use WithPagination;
    protected $paginationTheme = 'bootstrap';

    public $searchId;
    public $search_descripcion;
    public $search_name;
    public $search_fecha;
    public $search_customer;
    public $search_dni;

    public $titulo='Agregar Alumno';
    public $btn='Registrar';

    public $id_eliminar;
    public $id_identAlum=0;

    public $nombre;
    public $customer=0;
    public $dni;

    protected $listeners=['render'=>'render'];

    protected $rules=[
        "nombre"=>"required",
        "dni"=>"required|digits:8"
    ];

    protected $messages = [
        'nombre.required' => 'se debe ingresar un nombre.',
        'dni.required' => 'se debe ingresar un dni.',
        'dni.digits' => 'debe ser un número de 8 digitos.'
    ];
    
    public function render()
    {
        $datosSistem['identificador_alumno'] = identificador_alumno::
        select('identificador_alumno.id','identificador_alumno.name as descripcion','users.name','customer.nombre as Cusnombre', 'identificador_alumno.updated_at', 
        'identificador_alumno.dni')
        ->join('customer', 'customer.id', '=', 'identificador_alumno.id_customer' )
        ->join('users', 'users.id', '=', 'identificador_alumno.user_update' )
        ->where('identificador_alumno.id','like', '%'.$this->searchId.'%')
        ->where('identificador_alumno.name','like', '%'.$this->search_descripcion.'%')
        ->where('customer.nombre','like', '%'.$this->search_customer.'%')
        ->where('users.name','like', '%'.$this->search_name.'%')
        ->where('identificador_alumno.updated_at','like', '%'.$this->search_fecha.'%')
        ->where('identificador_alumno.dni','like', '%'.$this->search_dni.'%')
        ->where('identificador_alumno.estado', 1)
        ->orderBy('identificador_alumno.id','desc')
        ->paginate(10);

        $datosSistem['customer_select'] = customer::
        select('id','nombre')
        ->where('estado', 1)
        ->orderBy('id','asc')
        ->get();

        return view('livewire.identalumnwire', compact('datosSistem'));
    }

    public function save(){
        $this->validate();

        if($this->customer==0){
            $this->emit('alertError','se debe seleccionar un padre.');
        }else{
            if($this->id_identAlum==0){

                $identificador_alumno = identificador_alumno::
                select('id')
                ->where('name', trim($this->nombre))
                ->where('id_customer', $this->customer)
                ->where('estado',1)
                ->get();
        
                $validExist=0;
                $mensajeError="";
                foreach($identificador_alumno as $row){
                    $validExist++;
                    $mensajeError=$mensajeError. PHP_EOL .'* El nombre ingresado está siendo utilizado.';
                }
    
                $identificador_alumnoDNI = identificador_alumno::
                select('id')
                ->where('dni', trim($this->dni))
                ->where('estado',1)
                ->get();
            
                foreach($identificador_alumnoDNI as $row){
                    $validExist++;
                    $mensajeError=$mensajeError. PHP_EOL .'* El dni ingresado está siendo utilizado.';
                }
        
                if($validExist==0){
                    identificador_alumno::create([
                        'id_customer'=>$this->customer,
                        'name'=>trim($this->nombre),
                        'dni'=>$this->dni,
                        'estado'=>1,
                        'user_create'=>auth()->user()->id,
                        'user_update'=>auth()->user()->id
                    ]);
    
                    $this->reset(['id_eliminar', 'id_identAlum','titulo','btn','nombre','customer','dni']);
                    $this->emit('render');
                    $this->emit('alertOK','Se registro con exito.');
                }else{
                    $this->emit('alertError','error:'. 
                    $mensajeError);
                }
            }else{
                $identificador_alumno = identificador_alumno::
                select('id')
                ->where('name', trim($this->nombre))
                ->where('id','<>', $this->id_identAlum)
                ->where('id_customer', $this->customer)
                ->where('estado',1)
                ->get();
        
                $validExist=0;
                $mensajeError="";
                foreach($identificador_alumno as $row){
                    $validExist++;
                    $mensajeError=$mensajeError. PHP_EOL .'* El nombre ingresado está siendo utilizado.';
                }

                $identificador_alumnoDNI = identificador_alumno::
                select('id')
                ->where('dni', trim($this->dni))
                ->where('estado',1)
                ->get();
                
                foreach($identificador_alumnoDNI as $row){
                    $validExist++;
                    $mensajeError=$mensajeError. PHP_EOL .'* El dni ingresado está siendo utilizado.';
                }
    
                if($validExist==0){
                    identificador_alumno::where('id',$this->id_identAlum)
                    ->update([
                        'name'=>trim($this->nombre),
                        'id_customer'=>$this->customer,
                        'dni'=>$this->dni,
                        'user_update'=>auth()->user()->id
                    ]);
            
                    $this->reset(['id_eliminar', 'id_identAlum','titulo','btn','nombre','customer','dni']);
                    $this->emit('render');
                    $this->emit('alertOK','Se edito el registro con exito.');
                }else{
                    $this->emit('alertError','error:'. 
                    $mensajeError);
                }
            }
        }
    }

    public function eliminarID($id){
        $this->id_eliminar=$id;
    }

    public function delete_alumIdent(){
        identificador_alumno::where('id',$this->id_eliminar)
        ->update([
        'estado'=>0,
        'user_update'=>auth()->user()->id]);

        $this->reset(['id_eliminar', 'id_identAlum','titulo','btn','nombre','customer','dni']);
        $this->emit('render');
        $this->emit('alertOK','Se elimino la marca con exito.');
    }

    public function modificarID($id){
        $this->id_identAlum=$id;

        $identificador_alumno = identificador_alumno::
        select('name','id_customer','dni')
        ->where('id', $id)
        ->get();

        foreach($identificador_alumno as $row){
            $this->nombre=$row->name;
            $this->customer=$row->id_customer;
            $this->dni=$row->dni;
        }

        $this->titulo='Editar Alumno N° '. $id;
        $this->btn='Editar';

    }

    public function limpiar(){
        $this->reset(['id_eliminar', 'id_identAlum','titulo','btn','nombre','customer','dni']);
    }

    public function updatingSearchid(){
        $this->resetPage();
    }

    public function updatingSearchname(){
        $this->resetPage();
    }

    public function updatingSearchdescripcion(){
        $this->resetPage();
    }

    public function updatingSearchfecha(){
        $this->resetPage();
    }

    public function updatingSearchcustomer(){
        $this->resetPage();
    }

    public function updatingSearchdni(){
        $this->resetPage();
    }

}
