<?php

namespace App\Http\Livewire;

use App\Models\local;
use App\Models\print_pdf_voucher;
use App\Models\warehouses;
use Livewire\Component;
use Livewire\WithFileUploads;
use Livewire\WithPagination;

class Localwire extends Component
{
    use WithFileUploads;
    use WithPagination;
    protected $paginationTheme = 'bootstrap';
    
    public $searchId;
    public $search_codigo;
    public $search_nombre;
    public $search_codigoSunat;
    public $search_direccion;
    public $search_almacen;
    public $search_impresion;
    public $search_Ffactura;
    public $search_Fboleta;
    public $search_FnotaV;
    public $search_Fcotizacion;
    public $search_FnotaF;
    public $search_FnotaB;
    public $search_Fguia;

    public $titulo='Agregar Local';
    public $btn='Registrar';

    public $id_eliminar;

    public $identif_imagen;

    public $codigo;
    public $descripcion;
    public $codigoSunat;
    public $id_almacen=1;
    public $direccion;
    public $Ffactura;
    public $Fboleta;
    public $FnotaV;
    public $Fcotiza;
    public $FncF;
    public $FncB;
    public $Fguia;
    public $id_print=1;
    public $logoPDF;

    public $imgMostrar;

    public $id_local=0;
    public $imagen_edit='0';

    protected $listeners=['render'=>'render'];

    protected $rules=[
        "codigo"=>"required",
        "descripcion"=>"required",
        "codigoSunat"=>"required",
        "direccion"=>"required",
        "Ffactura"=>"required",
        "Fboleta"=>"required",
        "FnotaV"=>"required",
        "Fcotiza"=>"required",
        "FncF"=>"required",
        "FncB"=>"required",
        "Fguia"=>"required",
        "logoPDF"=>"required|image",
    ];

    protected $messages = [
        'codigo.required' => 'se debe ingresar un codigo.',
        'descripcion.required' => 'se debe ingresar un nombre para el local.',
        'codigoSunat.required' => 'se debe ingresar el codigo de local de sunat (4 digitos).',
        'direccion.required' => 'se debe ingresar una dirección.',
        'Ffactura.required' => 'se debe ingresar un formato para las facturas.',
        'Fboleta.required' => 'se debe ingresar un formato para las boletas.',
        'FnotaV.required' => 'se debe ingresar un formato para las notas de venta.',
        'Fcotiza.required' => 'se debe ingresar un formato para las cotizaciones.',
        'FncF.required' => 'se debe ingresar un formato para las notas de credito - factura.',
        'FncB.required' => 'se debe ingresar un formato para las notas de credito - boleta.',
        'Fguia.required' => 'se debe ingresar un formato para las guias de remision.',

        'logoPDF.required' => 'se debe cargar una imagen.',
        'logoPDF.image' => 'el archivo debe ser una imagen.',
    ];

    public function mount(){
        $this->identif_imagen=rand();
    }

    public function render()
    {
        $datosSistem['local'] = local::
        select('local.id','local.codigo','local.nombre', 'local.codigo_local_sunat','local.direccion','warehouses.name as namewarehouses',
        'print_pdf_voucher.descripcion as namePrint', 'img_pdf','factura_format','boleta_format','notaVenta_format','cotizacion_format',
        'notaCreditF_format','notaCreditB_format','guiaRemis_format')
        ->join('warehouses', 'warehouses.id', '=', 'local.id_warehouse' )
        ->join('print_pdf_voucher', 'print_pdf_voucher.id', '=', 'local.id_print_pdf_voucher' )
        ->where('local.id','like', '%'.$this->searchId.'%')
        ->where('local.codigo','like', '%'.$this->search_codigo.'%')
        ->where('local.nombre','like', '%'.$this->search_nombre.'%')
        ->where('local.codigo_local_sunat','like', '%'.$this->search_codigoSunat.'%')
        ->where('local.direccion','like', '%'.$this->search_direccion.'%')
        ->where('warehouses.name','like', '%'.$this->search_almacen.'%')
        ->where('print_pdf_voucher.descripcion','like', '%'.$this->search_impresion.'%')
        ->where('local.factura_format','like', '%'.$this->search_Ffactura.'%')
        ->where('local.boleta_format','like', '%'.$this->search_Fboleta.'%')
        ->where('local.notaVenta_format','like', '%'.$this->search_FnotaV.'%')
        ->where('local.cotizacion_format','like', '%'.$this->search_Fcotizacion.'%')
        ->where('local.notaCreditF_format','like', '%'.$this->search_FnotaF.'%')
        ->where('local.notaCreditB_format','like', '%'.$this->search_FnotaB.'%')
        ->where('local.guiaRemis_format','like', '%'.$this->search_Fguia.'%')
        ->where('local.estado', 1)
        ->orderBy('local.id','desc')
        ->paginate(10);
        
        $datosSistem['warehouses'] = warehouses::
        select('id','name as descripcion')
        ->where('estado', 1)
        ->orderBy('id','asc')
        ->get();

        $datosSistem['print_pdf_voucher'] = print_pdf_voucher::
        select('id','descripcion')
        ->where('estado', 1)
        ->orderBy('id','asc')
        ->get();

        return view('livewire.localwire', compact('datosSistem'));
    }

    public function save(){

        if($this->id_local==0){

            $this->validate();

            $localN = local::
            select('id')
            ->where('nombre', trim($this->descripcion))
            ->where('estado',1)
            ->get();
        
            $validExistNom=0;
            foreach($localN as $rowN){
                $validExistNom++;
            }

            $localC = local::
            select('id')
            ->where('codigo', trim($this->codigo))
            ->where('estado',1)
            ->get();
        
            $validExistCod=0;
            foreach($localC as $rowC){
                $validExistCod++;
            }

            if($validExistNom==0 && $validExistCod==0){

                $name_img=rand() .'_'.date('Y-m-d H:i:s');
                $name_img=str_replace('-','_',$name_img);
                $name_img=str_replace(' ','_',$name_img);
                $name_img=str_replace(':','_',$name_img);
                $this->logoPDF->storeAs('/assets_admin/images/logos/',$name_img.'.jpg','public_uploads');

                local::create([
                    'codigo_local_sunat'=>trim($this->codigoSunat),
                    'codigo'=>trim($this->codigo),
                    'nombre'=>trim($this->descripcion),
                    'direccion'=>trim($this->direccion),
                    'id_warehouse'=>$this->id_almacen,
                    'id_print_pdf_voucher'=>$this->id_print,
                    'factura_format'=>trim($this->Ffactura),
                    'boleta_format'=>trim($this->Fboleta),
                    'notaVenta_format'=>trim($this->FnotaV),
                    'cotizacion_format'=>trim($this->Fcotiza),
                    'notaCreditF_format'=>trim($this->FncF),
                    'notaCreditB_format'=>trim($this->FncB),
                    'guiaRemis_format'=>trim($this->Fguia),

                    'estado'=>1,
                    'user_create'=>auth()->user()->id,
                    'user_update'=>auth()->user()->id,
                    'img_pdf'=>'/'.$name_img.'.jpg'
                ]);

                $this->reset(['titulo','btn','id_eliminar','identif_imagen','codigo','descripcion','codigoSunat','id_almacen','direccion',
                'Ffactura','Fboleta','FnotaV','Fcotiza','FncF','FncB','Fguia','id_print','logoPDF','imgMostrar','id_local','imagen_edit']);
                $this->identif_imagen=rand();
                $this->emit('render');
                $this->emit('cerrarModal');
                $this->emit('alertOK','Se registro el local con exito.');

            }else{
                if($validExistNom>0){
                    if($validExistCod>0){
                        $this->emit('alertError','El codigo y el nombre del local fueron utilizados anteriormente.');
                    }else{
                        $this->emit('alertError','El nombre del local fue utilizado anteriormente.');
                    }
                }else{
                    $this->emit('alertError','El codigo ya fue utilizado anteriormente.');
                }
            }

        }else{

            $error_msj=0;
            $MensajeError='';

            if($this->codigo=="" || is_null($this->codigo)){
                $MensajeError=$MensajeError. PHP_EOL .'* Ingresar un codigo';
                $error_msj++;
            }

            if($this->descripcion=="" || is_null($this->descripcion)){
                $MensajeError=$MensajeError. PHP_EOL .'* Ingresar un nombre';
                $error_msj++;
            }

            if($this->codigoSunat=="" || is_null($this->codigoSunat)){
                $MensajeError=$MensajeError. PHP_EOL .'* Ingresar un codigo de local - sunat';
                $error_msj++;
            }

            if($this->direccion=="" || is_null($this->direccion)){
                $MensajeError=$MensajeError. PHP_EOL .'* Ingresar una dirección';
                $error_msj++;
            }

            if($this->Ffactura=="" || is_null($this->Ffactura)){
                $MensajeError=$MensajeError. PHP_EOL .'* Ingresar un formato de factura';
                $error_msj++;
            }

            if($this->Fboleta=="" || is_null($this->Fboleta)){
                $MensajeError=$MensajeError. PHP_EOL .'* Ingresar un formato de boleta';
                $error_msj++;
            }

            if($this->FnotaV=="" || is_null($this->FnotaV)){
                $MensajeError=$MensajeError. PHP_EOL .'* Ingresar un formato de nota de venta';
                $error_msj++;
            }

            if($this->Fcotiza=="" || is_null($this->Fcotiza)){
                $MensajeError=$MensajeError. PHP_EOL .'* Ingresar un formato de cotización';
                $error_msj++;
            }

            if($this->FncF=="" || is_null($this->FncF)){
                $MensajeError=$MensajeError. PHP_EOL .'* Ingresar un formato de nota de credito - factura';
                $error_msj++;
            }

            if($this->FncB=="" || is_null($this->FncB)){
                $MensajeError=$MensajeError. PHP_EOL .'* Ingresar un formato de nota de credito - boleta';
                $error_msj++;
            }

            if($this->Fguia=="" || is_null($this->Fguia)){
                $MensajeError=$MensajeError. PHP_EOL .'* Ingresar un formato de guia de remision';
                $error_msj++;
            }

            if($error_msj==0){
                $localN = local::
                select('id')
                ->where('nombre', trim($this->descripcion))
                ->where('estado',1)
                ->where('id','!=',$this->id_local)
                ->get();
            
                $validExistNom=0;
                foreach($localN as $rowN){
                    $validExistNom++;
                }

                $localC = local::
                select('id')
                ->where('codigo', trim($this->codigo))
                ->where('estado',1)
                ->where('id','!=',$this->id_local)
                ->get();
            
                $validExistCod=0;
                foreach($localC as $rowC){
                    $validExistCod++;
                }

                if($validExistNom==0 && $validExistCod==0){

                    if($this->logoPDF){
                        $name_img=rand() .'_'.date('Y-m-d H:i:s');
                        $name_img=str_replace('-','_',$name_img);
                        $name_img=str_replace(' ','_',$name_img);
                        $name_img=str_replace(':','_',$name_img);
                        $this->logoPDF->storeAs('/assets_admin/images/logos/',$name_img.'.jpg','public_uploads');
        
                        local::where('id',$this->id_local)
                        ->update([
                            'codigo_local_sunat'=>trim($this->codigoSunat),
                            'codigo'=>trim($this->codigo),
                            'nombre'=>trim($this->descripcion),
                            'direccion'=>trim($this->direccion),
                            'id_warehouse'=>$this->id_almacen,
                            'id_print_pdf_voucher'=>$this->id_print,
                            'factura_format'=>trim($this->Ffactura),
                            'boleta_format'=>trim($this->Fboleta),
                            'notaVenta_format'=>trim($this->FnotaV),
                            'cotizacion_format'=>trim($this->Fcotiza),
                            'notaCreditF_format'=>trim($this->FncF),
                            'notaCreditB_format'=>trim($this->FncB),
                            'guiaRemis_format'=>trim($this->Fguia),
        
                            'estado'=>1,
                            'user_update'=>auth()->user()->id,
                            'img_pdf'=>'/'.$name_img.'.jpg'
                        ]);
                    }else{
                        local::where('id',$this->id_local)
                        ->update([
                            'codigo_local_sunat'=>trim($this->codigoSunat),
                            'codigo'=>trim($this->codigo),
                            'nombre'=>trim($this->descripcion),
                            'direccion'=>trim($this->direccion),
                            'id_warehouse'=>$this->id_almacen,
                            'id_print_pdf_voucher'=>$this->id_print,
                            'factura_format'=>trim($this->Ffactura),
                            'boleta_format'=>trim($this->Fboleta),
                            'notaVenta_format'=>trim($this->FnotaV),
                            'cotizacion_format'=>trim($this->Fcotiza),
                            'notaCreditF_format'=>trim($this->FncF),
                            'notaCreditB_format'=>trim($this->FncB),
                            'guiaRemis_format'=>trim($this->Fguia),
        
                            'estado'=>1,
                            'user_update'=>auth()->user()->id,
                        ]);
                    }

                    $this->reset(['titulo','btn','id_eliminar','identif_imagen','codigo','descripcion','codigoSunat','id_almacen','direccion',
                    'Ffactura','Fboleta','FnotaV','Fcotiza','FncF','FncB','Fguia','id_print','logoPDF','imgMostrar','id_local','imagen_edit']);
                    $this->identif_imagen=rand();
                    $this->emit('render');
                    $this->emit('cerrarModal');
                    $this->emit('alertOK','Se registro el local con exito.');

                }else{
                    if($validExistNom>0){
                        if($validExistCod>0){
                            $this->emit('alertError','El codigo y el nombre del local fueron utilizados anteriormente.');
                        }else{
                            $this->emit('alertError','El nombre del local fue utilizado anteriormente.');
                        }
                    }else{
                        $this->emit('alertError','El codigo ya fue utilizado anteriormente.');
                    }
                }
            }else{
                $this->emit('alertError','para modificar el registro se debe:'. 
                $MensajeError);
            }

        }

    }

    public function limpiar(){
        $this->identif_imagen=rand();
        $this->reset(['titulo','btn','id_eliminar','identif_imagen','codigo','descripcion','codigoSunat','id_almacen','direccion',
        'Ffactura','Fboleta','FnotaV','Fcotiza','FncF','FncB','Fguia','id_print','logoPDF','imgMostrar','id_local','imagen_edit']);
        $this->emit('render');
    }

    public function modificarID($id){
        $this->id_local=$id;

        $Categoria = local::
        select('local.codigo','local.nombre', 'local.codigo_local_sunat','local.direccion','id_warehouse',
        'id_print_pdf_voucher', 'img_pdf','factura_format','boleta_format','notaVenta_format','cotizacion_format',
        'notaCreditF_format','notaCreditB_format','guiaRemis_format')
        ->where('local.id', $id)
        ->get();

        foreach($Categoria as $row){
            $this->codigoSunat=$row->codigo_local_sunat;
            $this->codigo=$row->codigo;
            $this->descripcion=$row->nombre;
            $this->direccion=$row->direccion;
            $this->id_almacen=(String)$row->id_warehouse;
            $this->id_print=(String)$row->id_print_pdf_voucher;
            $this->Ffactura=$row->factura_format;
            $this->Fboleta=$row->boleta_format;
            $this->FnotaV=$row->notaVenta_format;
            $this->Fcotiza=$row->cotizacion_format;
            $this->FncF=$row->notaCreditF_format;
            $this->FncB=$row->notaCreditB_format;
            $this->Fguia=$row->guiaRemis_format;
            $this->imagen_edit=asset('assets_admin/images/logos'.$row->img_pdf);
        }

        $this->titulo='Editar Local N° '. $id;
        $this->btn='Editar';

    }

    public function mostrarIMG($id){

        $local = local::
        select('img_pdf')
        ->where('id', $id)
        ->get();

        foreach($local as $row){
            $this->imgMostrar=asset('assets_admin/images/logos'.$row->img_pdf);
        }
    }

    public function eliminarID($id){
        $this->id_eliminar=$id;
    }

    public function delete_local(){
        local::where('id',$this->id_eliminar)
        ->update([
        'estado'=>0,
        'user_update'=>auth()->user()->id]);

        $this->identif_imagen=rand();
        $this->reset(['titulo','btn','id_eliminar','identif_imagen','codigo','descripcion','codigoSunat','id_almacen','direccion',
        'Ffactura','Fboleta','FnotaV','Fcotiza','FncF','FncB','Fguia','id_print','logoPDF','imgMostrar','id_local','imagen_edit']);
        $this->emit('render');
        $this->emit('alertOK','Se elimino el local con exito.');
    }

    public function updatingSearchid(){
        $this->resetPage();
    }

    public function updatingSearchcodigo(){
        $this->resetPage();
    }

    public function updatingSearchnombre(){
        $this->resetPage();
    }

    public function updatingSearchcodigosunat(){
        $this->resetPage();
    }

    public function updatingSearchdireccion(){
        $this->resetPage();
    }

    public function updatingSearchalmacen(){
        $this->resetPage();
    }

    public function updatingSearchimpresion(){
        $this->resetPage();
    }

    public function updatingSearchffactura(){
        $this->resetPage();
    }

    public function updatingSearchfboleta(){
        $this->resetPage();
    }

    public function updatingSearchfnotav(){
        $this->resetPage();
    }

    public function updatingSearchfcotizacion(){
        $this->resetPage();
    }

    public function updatingSearchfnotaf(){
        $this->resetPage();
    }

    public function updatingSearchfnotab(){
        $this->resetPage();
    }

    public function updatingSearchfguia(){
        $this->resetPage();
    }

}
