<?php

namespace App\Http\Livewire;

use App\Models\mark;
use Livewire\Component;
use Livewire\WithPagination;

class Markwire extends Component
{
    use WithPagination;
    protected $paginationTheme = 'bootstrap';
    
    public $searchId;
    public $search_descripcion;
    public $search_name;
    public $search_fecha;

    public $descripcion;

    public $titulo='Agregar Marca';
    public $btn='Registrar';

    public $id_eliminar;
    public $id_almacen=0;

    protected $listeners=['render'=>'render'];

    protected $rules=[
        "descripcion"=>"required"
    ];

    protected $messages = [
        'descripcion.required' => 'se debe ingresar un nombre para la marca.'
    ];

    public function render()
    {
        $datosSistem['mark'] = mark::
        select('mark.id','mark.name as descripcion','users.name', 'mark.updated_at')
        ->join('users', 'users.id', '=', 'mark.user_update' )
        ->where('mark.id','like', '%'.$this->searchId.'%')
        ->where('mark.name','like', '%'.$this->search_descripcion.'%')
        ->where('users.name','like', '%'.$this->search_name.'%')
        ->where('mark.updated_at','like', '%'.$this->search_fecha.'%')
        ->where('mark.estado', 1)
        ->orderBy('mark.id','desc')
        ->paginate(10);

        return view('livewire.markwire', compact('datosSistem'));
    }

    public function save(){

        $this->validate();

        if($this->id_almacen==0){
            $mark = mark::
            select('id')
            ->where('name', trim($this->descripcion))
            ->where('estado',1)
            ->get();
    
            $validExist=0;
            foreach($mark as $row){
                $validExist++;
            }
    
            if($validExist==0){
                mark::create([
                    'name'=>trim($this->descripcion),
                    'estado'=>1,
                    'user_create'=>auth()->user()->id,
                    'user_update'=>auth()->user()->id
                ]);
        
                $this->reset(['id_eliminar', 'descripcion','titulo','btn','id_almacen']);
                $this->emit('render');
                $this->emit('alertOK','Se registro la marca con exito.');
            }else{
                $this->emit('alertError','El nombre ingresado está siendo utilizado en otra marca.');
            }
        }else{
            $mark = mark::
            select('id')
            ->where('name', trim($this->descripcion))
            ->where('id','<>', $this->id_almacen)
            ->where('estado',1)
            ->get();
    
            $validExist=0;
            foreach($mark as $row){
                $validExist++;
            }

            if($validExist==0){
                mark::where('id',$this->id_almacen)
                ->update([
                    'name'=>trim($this->descripcion),
                    'user_update'=>auth()->user()->id
                ]);
        
                $this->reset(['id_eliminar', 'descripcion','titulo','btn','id_almacen']);
                $this->emit('render');
                $this->emit('alertOK','Se edito la marca con exito.');
            }else{
                $this->emit('alertError','El nombre ingresado está siendo utilizado en otra marca.');
            }
        }
        
    }

    public function eliminarID($id){
        $this->id_eliminar=$id;
    }

    public function delete_categoria(){
        mark::where('id',$this->id_eliminar)
        ->update([
        'estado'=>0,
        'user_update'=>auth()->user()->id]);

        $this->reset(['id_eliminar', 'descripcion','titulo','btn','id_almacen']);
        $this->emit('render');
        $this->emit('alertOK','Se elimino la marca con exito.');
    }

    public function modificarID($id){
        $this->id_almacen=$id;

        $mark = mark::
        select('name')
        ->where('id', $id)
        ->get();

        foreach($mark as $row){
            $this->descripcion=$row->name;
        }

        $this->titulo='Editar Marca N° '. $id;
        $this->btn='Editar';

    }

    public function limpiar(){
        $this->reset(['id_eliminar', 'descripcion','titulo','btn','id_almacen']);
    }

    public function updatingSearchid(){
        $this->resetPage();
    }

    public function updatingSearchname(){
        $this->resetPage();
    }

    public function updatingSearchdescripcion(){
        $this->resetPage();
    }

    public function updatingSearchfecha(){
        $this->resetPage();
    }
    
}
