<?php

namespace App\Http\Livewire;

use App\Models\warehouses;
use Illuminate\Support\Facades\DB;
use Carbon\Carbon;
use Livewire\Component;
use Livewire\WithPagination;

class Warehouseswire extends Component
{
    use WithPagination;
    protected $paginationTheme = 'bootstrap';
    
    public $searchId;
    public $search_descripcion;
    public $search_name;
    public $search_fecha;

    public $descripcionAlmacen;

    public $titulo='Agregar Almacén';
    public $btn='Registrar';

    public $id_eliminar;
    public $id_almacen=0;

    protected $listeners=['render'=>'render'];

    protected $rules=[
        "descripcionAlmacen"=>"required"
    ];

    protected $messages = [
        'descripcionAlmacen.required' => 'se debe ingresar un nombre para el almacén.'
    ];

    public function render()
    {
        $datosSistem['warehouses'] = warehouses::
        select('warehouses.id','warehouses.name as descripcion','users.name', 'warehouses.updated_at')
        ->join('users', 'users.id', '=', 'warehouses.user_update' )
        ->where('warehouses.id','like', '%'.$this->searchId.'%')
        ->where('warehouses.name','like', '%'.$this->search_descripcion.'%')
        ->where('users.name','like', '%'.$this->search_name.'%')
        ->where('warehouses.updated_at','like', '%'.$this->search_fecha.'%')
        ->where('warehouses.estado', 1)
        ->orderBy('warehouses.id','desc')
        ->paginate(10);

        return view('livewire.warehouseswire', compact('datosSistem'));
    }

    public function save(){

        $this->validate();

        if($this->id_almacen==0){
            $warehouses = warehouses::
            select('id')
            ->where('name', trim($this->descripcionAlmacen))
            ->where('estado',1)
            ->get();
    
            $validExist=0;
            foreach($warehouses as $row){
                $validExist++;
            }
    
            if($validExist==0){
                $mytime = Carbon::now();
        
                $fecha_reg=$mytime->toDateTimeString();

                $IDwarehouses = warehouses::create([
                    'name'=>trim($this->descripcionAlmacen),
                    'estado'=>1,
                    'user_create'=>auth()->user()->id,
                    'user_update'=>auth()->user()->id
                ])->id;

                DB::select('CALL create_stock_warehouse(?,?,?)', 
                    [auth()->user()->id, $fecha_reg, $IDwarehouses]);
        
                $this->reset(['id_eliminar', 'descripcionAlmacen','titulo','btn','id_almacen']);
                $this->emit('render');
                $this->emit('alertOK','Se registro el almacén con exito.');
            }else{
                $this->emit('alertError','El nombre ingresado está siendo utilizado en otro almacén.');
            }
        }else{
            $warehouses = warehouses::
            select('id')
            ->where('name', trim($this->descripcionAlmacen))
            ->where('id','<>', $this->id_almacen)
            ->where('estado',1)
            ->get();
    
            $validExist=0;
            foreach($warehouses as $row){
                $validExist++;
            }

            if($validExist==0){
                warehouses::where('id',$this->id_almacen)
                ->update([
                    'name'=>trim($this->descripcionAlmacen),
                    'user_update'=>auth()->user()->id
                ]);
        
                $this->reset(['id_eliminar', 'descripcionAlmacen','titulo','btn','id_almacen']);
                $this->emit('render');
                $this->emit('alertOK','Se edito el almacén con exito.');
            }else{
                $this->emit('alertError','El nombre ingresado está siendo utilizado en otro almacén.');
            }
        }
        
    }

    public function eliminarID($id){
        $this->id_eliminar=$id;
    }

    public function delete_categoria(){
        warehouses::where('id',$this->id_eliminar)
        ->update([
        'estado'=>0,
        'user_update'=>auth()->user()->id]);

        $this->reset(['id_eliminar', 'descripcionAlmacen','titulo','btn','id_almacen']);
        $this->emit('render');
        $this->emit('alertOK','Se elimino el almacén con exito.');
    }

    public function modificarID($id){
        $this->id_almacen=$id;

        $Categoria = warehouses::
        select('name')
        ->where('id', $id)
        ->get();

        foreach($Categoria as $row){
            $this->descripcionAlmacen=$row->name;
        }

        $this->titulo='Editar Almacén N° '. $id;
        $this->btn='Editar';

    }

    public function limpiar(){
        $this->reset(['id_eliminar', 'descripcionAlmacen','titulo','btn','id_almacen']);
    }

    public function updatingSearchid(){
        $this->resetPage();
    }

    public function updatingSearchname(){
        $this->resetPage();
    }

    public function updatingSearchdescripcion(){
        $this->resetPage();
    }

    public function updatingSearchfecha(){
        $this->resetPage();
    }
    
}
